@@ -31,7 +31,7 @@ class TestFlowConductorActor(unittest.TestCase):
 		data_dir = os.path.join(actorstestutils.current_dirpath(__file__), 'data')
 
 		config_builder = configuration.LongTangConfigurationBuilder()
-		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).build()
+		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).download_cover_art(False).build()
 
 		actor_system = system.ActorSystem()
 		main_actor = actor_system.with_factory(factory.FlowConductorSupervisorFactory(config),'flowconductor-test-actor')
@@ -57,7 +57,7 @@ class TestFlowConductorActor(unittest.TestCase):
 		source_file_with_id3tag = actorstestutils.copy_to_tmp(source=os.path.join(data_dir, 'with_id3taginfo.mp3'),suffix='.tmp.mp3',dir=base_from_test_dir)
 
 		config_builder = configuration.LongTangConfigurationBuilder()
-		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).build()
+		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).download_cover_art(False).build()
 
 		flowconductor_actor = actorstestutils.TestActorBuilder().with_factory(factory.FlowConductorSupervisorFactory(config))\
 															.with_id('flowconductor-test-actor')\
@@ -102,7 +102,7 @@ class TestFlowConductorActor(unittest.TestCase):
 		source_file_with_id3tag = actorstestutils.copy_to_tmp(source=os.path.join(data_dir, 'invalid_metadata.mp3'),suffix='.tmp.mp3',dir=base_from_test_dir)		
 
 		config_builder = configuration.LongTangConfigurationBuilder()
-		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).build()
+		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).download_cover_art(False).build()
 
 		flowconductor_actor = actorstestutils.TestActorBuilder().with_factory(factory.FlowConductorSupervisorFactory(config))\
 															.with_id('flowconductor-test-actor')\
@@ -124,7 +124,7 @@ class TestFlowConductorActor(unittest.TestCase):
 	def test_single_file_processing_nonexisting_path(self):
 
 		config_builder = configuration.LongTangConfigurationBuilder()
-		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).build()
+		config = config_builder.read_from(base_from_test_dir).generate_at(base_to_test_dir).download_cover_art(False).build()
 
 		flowconductor_actor = actorstestutils.TestActorBuilder().with_factory(factory.FlowConductorSupervisorFactory(config))\
 															.with_id('flowconductor-test-actor')\
@@ -150,7 +150,7 @@ class TestFlowConductorActor(unittest.TestCase):
 		source_file_with_id3tag = actorstestutils.copy_to_tmp(source=os.path.join(data_dir, 'with_id3taginfo.mp3'),suffix='.tmp.mp3',dir=base_from_test_dir)
 
 		config_builder = configuration.LongTangConfigurationBuilder()
-		config = config_builder.read_from(base_from_test_dir).generate_at('/dummy').build()
+		config = config_builder.read_from(base_from_test_dir).generate_at('/dummy').download_cover_art(False).build()
 
 		flowconductor_actor = actorstestutils.TestActorBuilder().with_factory(factory.FlowConductorSupervisorFactory(config))\
 															.with_id('flowconductor-test-actor')\
