@@ -7,7 +7,7 @@ from longtang.common import interactions
 
 from hamcrest import *
 from longtang.system import system
-from longtang.actors import testutils, actors, messages
+from longtang.actors import actorstestutils, actors, messages
 
 class TestInteractions(unittest.TestCase):
 
